@@ -33,16 +33,23 @@
 #' @param .df2 Degrees of freedom, Inf is allowed.
 #' @param .ncp Non-centrality parameter.
 #' @param .num_sims The number of randomly generated simulations you want.
+#' @param .return_tibble A logical value indicating whether to return the result
+#' as a tibble. Default is TRUE.
 #'
 #' @examples
 #' tidy_f()
+#'
 #' @return
 #' A tibble of randomly generated data.
 #'
-#' @export
-#'
+#' @name tidy_f
+NULL
 
-tidy_f <- function(.n = 50, .df1 = 1, .df2 = 1, .ncp = 0, .num_sims = 1) {
+#' @export
+#' @rdname tidy_f
+
+tidy_f <- function(.n = 50, .df1 = 1, .df2 = 1, .ncp = 0, .num_sims = 1,
+                   .return_tibble = TRUE) {
 
   # Tidyeval ----
   n <- as.integer(.n)
@@ -50,6 +57,7 @@ tidy_f <- function(.n = 50, .df1 = 1, .df2 = 1, .ncp = 0, .num_sims = 1) {
   df1 <- as.numeric(.df1)
   df2 <- as.numeric(.df2)
   ncp <- as.numeric(.ncp)
+  ret_tbl <- as.logical(.return_tibble)
 
   # Checks ----
   if (!is.integer(n) | n < 0) {
@@ -81,18 +89,28 @@ tidy_f <- function(.n = 50, .df1 = 1, .df2 = 1, .ncp = 0, .num_sims = 1) {
   qs <- seq(0, 1, (1 / (n - 1)))
   ps <- qs
 
-  df <- dplyr::tibble(sim_number = as.factor(x)) %>%
-    dplyr::group_by(sim_number) %>%
-    dplyr::mutate(x = list(1:n)) %>%
-    dplyr::mutate(y = list(stats::rf(n = n, df1 = df1, df2 = df2, ncp = ncp))) %>%
-    dplyr::mutate(d = list(density(unlist(y), n = n)[c("x", "y")] %>%
-      purrr::set_names("dx", "dy") %>%
-      dplyr::as_tibble())) %>%
-    dplyr::mutate(p = list(stats::pf(unlist(y), df1 = df1, df2 = df2, ncp = ncp))) %>%
-    dplyr::mutate(q = list(stats::qf(unlist(p), df1 = df1, df2 = df2, ncp = ncp))) %>%
-    tidyr::unnest(cols = c(x, y, d, p, q)) %>%
-    dplyr::ungroup()
+  # Create a data.table with one row per simulation
+  df <- data.table::CJ(sim_number = factor(1:num_sims), x = 1:n)
 
+  # Group the data by sim_number and add columns for x and y
+  df[, y := stats::rf(n = .N, df1 = df1, df2 = df2, ncp = ncp)]
+
+  # Compute the density of the y values and add columns for dx and dy
+  df[, c("dx", "dy") := density(y, n = n)[c("x", "y")], by = sim_number]
+
+  # Compute the p-values for the y values and add a column for p
+  df[, p := stats::pf(y, df1 = df1, df2 = df2, ncp = ncp)]
+
+  # Compute the q-values for the p-values and add a column for q
+  df[, q := stats::qf(p, df1 = df1, df2 = df2, ncp = ncp)]
+
+  if(.return_tibble){
+    df <- dplyr::as_tibble(df)
+  } else {
+    data.table::setkey(df, NULL)
+  }
+
+  # Create a tibble with the parameter grid
   param_grid <- dplyr::tibble(.df1, .df2, .ncp)
 
   # Attach descriptive attributes to tibble
@@ -102,6 +120,7 @@ tidy_f <- function(.n = 50, .df1 = 1, .df2 = 1, .ncp = 0, .num_sims = 1) {
   attr(df, ".ncp") <- .ncp
   attr(df, ".n") <- .n
   attr(df, ".num_sims") <- .num_sims
+  attr(df, ".ret_tbl") <- .return_tibble
   attr(df, "tibble_type") <- "tidy_f"
   attr(df, "ps") <- ps
   attr(df, "qs") <- qs
