@@ -32,22 +32,30 @@
 #' @param .shape Must be positive.
 #' @param .min The lower bound of the support of the distribution.
 #' @param .num_sims The number of randomly generated simulations you want.
+#' @param .return_tibble A logical value indicating whether to return the result
+#' as a tibble. Default is TRUE.
 #'
 #' @examples
 #' tidy_pareto1()
+#'
 #' @return
 #' A tibble of randomly generated data.
 #'
-#' @export
-#'
+#' @name tidy_pareto1
+NULL
 
-tidy_pareto1 <- function(.n = 50, .shape = 1, .min = 1, .num_sims = 1) {
+#' @export
+#' @rdname tidy_pareto1
+
+tidy_pareto1 <- function(.n = 50, .shape = 1, .min = 1, .num_sims = 1,
+                         .return_tibble = TRUE) {
 
   # Tidyeval ----
   n <- as.integer(.n)
   num_sims <- as.integer(.num_sims)
   shape <- as.numeric(.shape)
   min <- as.numeric(.min)
+  ret_tbl <- as.logical(.return_tibble)
 
   # Checks ----
   if (!is.integer(n) | n < 0) {
@@ -84,18 +92,28 @@ tidy_pareto1 <- function(.n = 50, .shape = 1, .min = 1, .num_sims = 1) {
   qs <- seq(0, 1, (1 / (n - 1)))
   ps <- qs
 
-  df <- dplyr::tibble(sim_number = as.factor(x)) %>%
-    dplyr::group_by(sim_number) %>%
-    dplyr::mutate(x = list(1:n)) %>%
-    dplyr::mutate(y = list(actuar::rpareto1(n = n, shape = shape, min = min))) %>%
-    dplyr::mutate(d = list(density(unlist(y), n = n)[c("x", "y")] %>%
-      purrr::set_names("dx", "dy") %>%
-      dplyr::as_tibble())) %>%
-    dplyr::mutate(p = list(actuar::ppareto1(unlist(y), shape = shape, min = min))) %>%
-    dplyr::mutate(q = list(actuar::qpareto1(unlist(p), shape = shape, min = min))) %>%
-    tidyr::unnest(cols = c(x, y, d, p, q)) %>%
-    dplyr::ungroup()
+  # Create a data.table with one row per simulation
+  df <- data.table::CJ(sim_number = factor(1:num_sims), x = 1:n)
 
+  # Group the data by sim_number and add columns for x and y
+  df[, y := actuar::rpareto1(n = .N, shape = shape, min = min)]
+
+  # Compute the density of the y values and add columns for dx and dy
+  df[, c("dx", "dy") := density(y, n = n)[c("x", "y")], by = sim_number]
+
+  # Compute the p-values for the y values and add a column for p
+  df[, p := actuar::ppareto1(y, shape = shape, min = min)]
+
+  # Compute the q-values for the p-values and add a column for q
+  df[, q := actuar::qpareto1(p, shape = shape, min = min)]
+
+  if(.return_tibble){
+    df <- dplyr::as_tibble(df)
+  } else {
+    data.table::setkey(df, NULL)
+  }
+
+  # Create a tibble with the parameters
   param_grid <- dplyr::tibble(.shape, .min)
 
   # Attach descriptive attributes to tibble
@@ -104,6 +122,7 @@ tidy_pareto1 <- function(.n = 50, .shape = 1, .min = 1, .num_sims = 1) {
   attr(df, ".min") <- .min
   attr(df, ".n") <- .n
   attr(df, ".num_sims") <- .num_sims
+  attr(df, ".ret_tbl") <- .return_tibble
   attr(df, "tibble_type") <- "tidy_pareto_single_parameter"
   attr(df, "ps") <- ps
   attr(df, "qs") <- qs
