@@ -32,22 +32,30 @@
 #' @param .shape Shape parameter defaults to 0.
 #' @param .scale Scale parameter defaults to 1.
 #' @param .num_sims The number of randomly generated simulations you want.
+#' @param .return_tibble A logical value indicating whether to return the result
+#' as a tibble. Default is TRUE.
 #'
 #' @examples
 #' tidy_weibull()
+#'
 #' @return
 #' A tibble of randomly generated data.
 #'
-#' @export
-#'
+#' @name tidy_weibull
+NULL
 
-tidy_weibull <- function(.n = 50, .shape = 1, .scale = 1, .num_sims = 1) {
+#' @export
+#' @rdname tidy_weibull
+
+tidy_weibull <- function(.n = 50, .shape = 1, .scale = 1, .num_sims = 1,
+                         .return_tibble = TRUE) {
 
   # Tidyeval ----
   n <- as.integer(.n)
   num_sims <- as.integer(.num_sims)
   shape <- as.numeric(.shape)
   scale <- as.numeric(.scale)
+  ret_tbl <- as.logical(.return_tibble)
 
   # Checks ----
   if (!is.integer(n) | n < 0) {
@@ -80,18 +88,28 @@ tidy_weibull <- function(.n = 50, .shape = 1, .scale = 1, .num_sims = 1) {
   qs <- seq(0, 1, (1 / (n - 1)))
   ps <- qs
 
-  df <- dplyr::tibble(sim_number = as.factor(x)) %>%
-    dplyr::group_by(sim_number) %>%
-    dplyr::mutate(x = list(1:n)) %>%
-    dplyr::mutate(y = list(stats::rweibull(n = n, shape = shape, scale = scale))) %>%
-    dplyr::mutate(d = list(density(unlist(y), n = n)[c("x", "y")] %>%
-      purrr::set_names("dx", "dy") %>%
-      dplyr::as_tibble())) %>%
-    dplyr::mutate(p = list(stats::pweibull(unlist(y), shape = shape, scale = scale))) %>%
-    dplyr::mutate(q = list(stats::qweibull(unlist(p), shape = shape, scale = scale))) %>%
-    tidyr::unnest(cols = c(x, y, d, p, q)) %>%
-    dplyr::ungroup()
+  # Create a data.table with one row per simulation
+  df <- data.table::CJ(sim_number = factor(1:num_sims), x = 1:n)
 
+  # Group the data by sim_number and add columns for x and y
+  df[, y := stats::rweibull(n = .N, shape = shape, scale = scale)]
+
+  # Compute the density of the y values and add columns for dx and dy
+  df[, c("dx", "dy") := density(y, n = n)[c("x", "y")], by = sim_number]
+
+  # Compute the p-values for the y values and add a column for p
+  df[, p := stats::pweibull(y, shape = shape, scale = scale)]
+
+  # Compute the q-values for the p-values and add a column for q
+  df[, q := stats::qweibull(p, shape = shape, scale = scale)]
+
+  if(.return_tibble){
+    df <- dplyr::as_tibble(df)
+  } else {
+    data.table::setkey(df, NULL)
+  }
+
+  # Create a tibble with the parameter grid
   param_grid <- dplyr::tibble(.shape, .scale)
 
   # Attach descriptive attributes to tibble
@@ -100,6 +118,7 @@ tidy_weibull <- function(.n = 50, .shape = 1, .scale = 1, .num_sims = 1) {
   attr(df, ".scale") <- .scale
   attr(df, ".n") <- .n
   attr(df, ".num_sims") <- .num_sims
+  attr(df, ".ret_tbl") <- .return_tibble
   attr(df, "tibble_type") <- "tidy_weibull"
   attr(df, "ps") <- ps
   attr(df, "qs") <- qs
