@@ -32,21 +32,29 @@
 #' @param .n The number of randomly generated points you want.
 #' @param .prob A probability of success in each trial 0 < prob <= 1.
 #' @param .num_sims The number of randomly generated simulations you want.
+#' @param .return_tibble A logical value indicating whether to return the result
+#' as a tibble. Default is TRUE.
 #'
 #' @examples
 #' tidy_zero_truncated_geometric()
+#'
 #' @return
 #' A tibble of randomly generated data.
 #'
-#' @export
-#'
+#' @name tidy_zero_truncated_geometric
+NULL
 
-tidy_zero_truncated_geometric <- function(.n = 50, .prob = 1, .num_sims = 1) {
+#' @export
+#' @rdname tidy_zero_truncated_geometric
+
+tidy_zero_truncated_geometric <- function(.n = 50, .prob = 1, .num_sims = 1,
+                                          .return_tibble = TRUE) {
 
   # Tidyeval ----
   n <- as.integer(.n)
   num_sims <- as.integer(.num_sims)
   prob <- as.numeric(.prob)
+  ret_tbl <- as.logical(.return_tibble)
 
   # Checks ----
   if (!is.integer(n) | n < 0) {
@@ -76,18 +84,28 @@ tidy_zero_truncated_geometric <- function(.n = 50, .prob = 1, .num_sims = 1) {
   qs <- seq(0, 1, (1 / (n - 1)))
   ps <- qs
 
-  df <- dplyr::tibble(sim_number = as.factor(x)) %>%
-    dplyr::group_by(sim_number) %>%
-    dplyr::mutate(x = list(1:n)) %>%
-    dplyr::mutate(y = list(actuar::rztgeom(n = n, prob = prob))) %>%
-    dplyr::mutate(d = list(density(unlist(y), n = n)[c("x", "y")] %>%
-      purrr::set_names("dx", "dy") %>%
-      dplyr::as_tibble())) %>%
-    dplyr::mutate(p = list(actuar::pztgeom(unlist(y), prob = prob))) %>%
-    dplyr::mutate(q = list(actuar::qztgeom(unlist(p), prob = prob))) %>%
-    tidyr::unnest(cols = c(x, y, d, p, q)) %>%
-    dplyr::ungroup()
+  # Create a data.table with one row per simulation
+  df <- data.table::CJ(sim_number = factor(1:num_sims), x = 1:n)
 
+  # Group the data by sim_number and add columns for x and y
+  df[, y := actuar::rztgeom(n = .N, prob = prob)]
+
+  # Compute the density of the y values and add columns for dx and dy
+  df[, c("dx", "dy") := density(y, n = n)[c("x", "y")], by = sim_number]
+
+  # Compute the p-values for the y values and add a column for p
+  df[, p := actuar::pztgeom(y, prob = prob)]
+
+  # Compute the q-values for the p-values and add a column for q
+  df[, q := actuar::qztgeom(p, prob = prob)]
+
+  if(.return_tibble){
+    df <- dplyr::as_tibble(df)
+  } else {
+    data.table::setkey(df, NULL)
+  }
+
+  # Create a tibble of the parameter grid
   param_grid <- dplyr::tibble(.prob)
 
   # Attach descriptive attributes to tibble
@@ -95,6 +113,7 @@ tidy_zero_truncated_geometric <- function(.n = 50, .prob = 1, .num_sims = 1) {
   attr(df, ".prob") <- .prob
   attr(df, ".n") <- .n
   attr(df, ".num_sims") <- .num_sims
+  attr(df, ".ret_tbl") <- .return_tibble
   attr(df, "tibble_type") <- "tidy_zero_truncated_geometric"
   attr(df, "ps") <- ps
   attr(df, "qs") <- qs
